@@ -43,9 +43,11 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
     let shared_big_files_state = gui_data.shared_big_files_state.clone();
     let shared_same_invalid_symlinks = gui_data.shared_same_invalid_symlinks.clone();
     let tree_view_temporary_files_finder = gui_data.main_notebook.tree_view_temporary_files_finder.clone();
+    let tree_view_bad_extensions = gui_data.main_notebook.tree_view_bad_extensions.clone();
     let shared_temporary_files_state = gui_data.shared_temporary_files_state.clone();
     let shared_similar_images_state = gui_data.shared_similar_images_state.clone();
     let shared_similar_videos_state = gui_data.shared_similar_videos_state.clone();
+    let shared_bad_extensions_state = gui_data.shared_bad_extensions_state.clone();
     let tree_view_same_music_finder = gui_data.main_notebook.tree_view_same_music_finder.clone();
     let shared_same_music_state = gui_data.shared_same_music_state.clone();
     let buttons_names = gui_data.bottom_buttons.buttons_names;
@@ -173,11 +175,7 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                             (ColumnsDuplicates::Path as u32, &directory),
                                             (
                                                 ColumnsDuplicates::Modification as u32,
-                                                &(format!(
-                                                    "{} - ({})",
-                                                    NaiveDateTime::from_timestamp(base_file_entry.modified_date as i64, 0),
-                                                    base_file_entry.size.file_size(options::BINARY).unwrap()
-                                                )),
+                                                &(NaiveDateTime::from_timestamp(base_file_entry.modified_date as i64, 0).to_string()),
                                             ),
                                             (ColumnsDuplicates::ModificationAsSecs as u32, &(base_file_entry.modified_date)),
                                             (ColumnsDuplicates::Color as u32, &(HEADER_ROW_COLOR.to_string())),
@@ -197,11 +195,7 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                                 (ColumnsDuplicates::Path as u32, &directory),
                                                 (
                                                     ColumnsDuplicates::Modification as u32,
-                                                    &(format!(
-                                                        "{} - ({})",
-                                                        NaiveDateTime::from_timestamp(entry.modified_date as i64, 0),
-                                                        entry.size.file_size(options::BINARY).unwrap()
-                                                    )),
+                                                    &(NaiveDateTime::from_timestamp(entry.modified_date as i64, 0).to_string()),
                                                 ),
                                                 (ColumnsDuplicates::ModificationAsSecs as u32, &(entry.modified_date)),
                                                 (ColumnsDuplicates::Color as u32, &(MAIN_ROW_COLOR.to_string())),
@@ -1168,11 +1162,12 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
 
                         let music_similarity = *mf.get_music_similarity();
 
-                        let is_title = (MusicSimilarity::TITLE & music_similarity) != MusicSimilarity::NONE;
-                        let is_artist = (MusicSimilarity::ARTIST & music_similarity) != MusicSimilarity::NONE;
-                        let is_album_title = (MusicSimilarity::ALBUM_TITLE & music_similarity) != MusicSimilarity::NONE;
-                        let is_album_artist = (MusicSimilarity::ALBUM_ARTIST & music_similarity) != MusicSimilarity::NONE;
+                        let is_track_title = (MusicSimilarity::TRACK_TITLE & music_similarity) != MusicSimilarity::NONE;
+                        let is_track_artist = (MusicSimilarity::TRACK_ARTIST & music_similarity) != MusicSimilarity::NONE;
                         let is_year = (MusicSimilarity::YEAR & music_similarity) != MusicSimilarity::NONE;
+                        let is_bitrate = (MusicSimilarity::BITRATE & music_similarity) != MusicSimilarity::NONE;
+                        let is_length = (MusicSimilarity::LENGTH & music_similarity) != MusicSimilarity::NONE;
+                        let is_genre = (MusicSimilarity::GENRE & music_similarity) != MusicSimilarity::NONE;
 
                         if mf.get_use_reference() {
                             let vector = mf.get_similar_music_referenced();
@@ -1191,18 +1186,20 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                 };
 
                                 let (directory, file) = split_path(&base_file_entry.path);
-                                let values: [(u32, &dyn ToValue); 15] = [
+                                let values: [(u32, &dyn ToValue); 17] = [
                                     (ColumnsSameMusic::ActivatableSelectButton as u32, &false),
                                     (ColumnsSameMusic::SelectionButton as u32, &false),
                                     (ColumnsSameMusic::Size as u32, &base_file_entry.size.file_size(options::BINARY).unwrap()),
                                     (ColumnsSameMusic::SizeAsBytes as u32, &base_file_entry.size),
                                     (ColumnsSameMusic::Name as u32, &file),
                                     (ColumnsSameMusic::Path as u32, &directory),
-                                    (ColumnsSameMusic::Title as u32, &base_file_entry.title),
-                                    (ColumnsSameMusic::Artist as u32, &base_file_entry.artist),
-                                    (ColumnsSameMusic::AlbumTitle as u32, &base_file_entry.album_title),
-                                    (ColumnsSameMusic::AlbumArtist as u32, &base_file_entry.album_artist),
+                                    (ColumnsSameMusic::Title as u32, &base_file_entry.track_title),
+                                    (ColumnsSameMusic::Artist as u32, &base_file_entry.track_artist),
                                     (ColumnsSameMusic::Year as u32, &base_file_entry.year.to_string()),
+                                    (ColumnsSameMusic::Genre as u32, &base_file_entry.genre),
+                                    (ColumnsSameMusic::Bitrate as u32, &(format!("{} kbps", base_file_entry.bitrate))),
+                                    (ColumnsSameMusic::BitrateAsNumber as u32, &(base_file_entry.bitrate)),
+                                    (ColumnsSameMusic::Length as u32, &base_file_entry.length),
                                     (
                                         ColumnsSameMusic::Modification as u32,
                                         &(NaiveDateTime::from_timestamp(base_file_entry.modified_date as i64, 0).to_string()),
@@ -1214,18 +1211,20 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                 list_store.set(&list_store.append(), &values);
                                 for file_entry in vec_file_entry {
                                     let (directory, file) = split_path(&file_entry.path);
-                                    let values: [(u32, &dyn ToValue); 15] = [
+                                    let values: [(u32, &dyn ToValue); 17] = [
                                         (ColumnsSameMusic::ActivatableSelectButton as u32, &true),
                                         (ColumnsSameMusic::SelectionButton as u32, &false),
                                         (ColumnsSameMusic::Size as u32, &file_entry.size.file_size(options::BINARY).unwrap()),
                                         (ColumnsSameMusic::SizeAsBytes as u32, &file_entry.size),
                                         (ColumnsSameMusic::Name as u32, &file),
                                         (ColumnsSameMusic::Path as u32, &directory),
-                                        (ColumnsSameMusic::Title as u32, &file_entry.title),
-                                        (ColumnsSameMusic::Artist as u32, &file_entry.artist),
-                                        (ColumnsSameMusic::AlbumTitle as u32, &file_entry.album_title),
-                                        (ColumnsSameMusic::AlbumArtist as u32, &file_entry.album_artist),
-                                        (ColumnsSameMusic::Year as u32, &file_entry.year.to_string()),
+                                        (ColumnsSameMusic::Title as u32, &base_file_entry.track_title),
+                                        (ColumnsSameMusic::Artist as u32, &base_file_entry.track_artist),
+                                        (ColumnsSameMusic::Year as u32, &base_file_entry.year.to_string()),
+                                        (ColumnsSameMusic::Genre as u32, &base_file_entry.genre),
+                                        (ColumnsSameMusic::Bitrate as u32, &(format!("{} kbps", base_file_entry.bitrate))),
+                                        (ColumnsSameMusic::BitrateAsNumber as u32, &(base_file_entry.bitrate)),
+                                        (ColumnsSameMusic::Length as u32, &base_file_entry.length),
                                         (
                                             ColumnsSameMusic::Modification as u32,
                                             &(NaiveDateTime::from_timestamp(file_entry.modified_date as i64, 0).to_string()),
@@ -1255,7 +1254,7 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                     vec_file_entry.clone()
                                 };
 
-                                let values: [(u32, &dyn ToValue); 15] = [
+                                let values: [(u32, &dyn ToValue); 17] = [
                                     (ColumnsSameMusic::ActivatableSelectButton as u32, &false),
                                     (ColumnsSameMusic::SelectionButton as u32, &false),
                                     (ColumnsSameMusic::Size as u32, &"".to_string()),
@@ -1264,28 +1263,14 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                     (ColumnsSameMusic::Path as u32, &"".to_string()),
                                     (
                                         ColumnsSameMusic::Title as u32,
-                                        &(match is_title {
+                                        &(match is_track_title {
                                             true => text.clone(),
                                             false => "".to_string(),
                                         }),
                                     ),
                                     (
                                         ColumnsSameMusic::Artist as u32,
-                                        &(match is_artist {
-                                            true => text.clone(),
-                                            false => "".to_string(),
-                                        }),
-                                    ),
-                                    (
-                                        ColumnsSameMusic::AlbumTitle as u32,
-                                        &(match is_album_title {
-                                            true => text.clone(),
-                                            false => "".to_string(),
-                                        }),
-                                    ),
-                                    (
-                                        ColumnsSameMusic::AlbumArtist as u32,
-                                        &(match is_album_artist {
+                                        &(match is_track_artist {
                                             true => text.clone(),
                                             false => "".to_string(),
                                         }),
@@ -1297,6 +1282,28 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                             false => "".to_string(),
                                         }),
                                     ),
+                                    (
+                                        ColumnsSameMusic::Bitrate as u32,
+                                        &(match is_bitrate {
+                                            true => text.clone(),
+                                            false => "".to_string(),
+                                        }),
+                                    ),
+                                    (ColumnsSameMusic::BitrateAsNumber as u32, &(0)),
+                                    (
+                                        ColumnsSameMusic::Genre as u32,
+                                        &(match is_genre {
+                                            true => text.clone(),
+                                            false => "".to_string(),
+                                        }),
+                                    ),
+                                    (
+                                        ColumnsSameMusic::Length as u32,
+                                        &(match is_length {
+                                            true => text.clone(),
+                                            false => "".to_string(),
+                                        }),
+                                    ),
                                     (ColumnsSameMusic::Modification as u32, &"".to_string()),
                                     (ColumnsSameMusic::ModificationAsSecs as u32, &(0)),
                                     (ColumnsSameMusic::Color as u32, &(HEADER_ROW_COLOR.to_string())),
@@ -1305,18 +1312,20 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                                 list_store.set(&list_store.append(), &values);
                                 for file_entry in vec_file_entry {
                                     let (directory, file) = split_path(&file_entry.path);
-                                    let values: [(u32, &dyn ToValue); 15] = [
+                                    let values: [(u32, &dyn ToValue); 17] = [
                                         (ColumnsSameMusic::ActivatableSelectButton as u32, &true),
                                         (ColumnsSameMusic::SelectionButton as u32, &false),
                                         (ColumnsSameMusic::Size as u32, &file_entry.size.file_size(options::BINARY).unwrap()),
                                         (ColumnsSameMusic::SizeAsBytes as u32, &file_entry.size),
                                         (ColumnsSameMusic::Name as u32, &file),
                                         (ColumnsSameMusic::Path as u32, &directory),
-                                        (ColumnsSameMusic::Title as u32, &file_entry.title),
-                                        (ColumnsSameMusic::Artist as u32, &file_entry.artist),
-                                        (ColumnsSameMusic::AlbumTitle as u32, &file_entry.album_title),
-                                        (ColumnsSameMusic::AlbumArtist as u32, &file_entry.album_artist),
+                                        (ColumnsSameMusic::Title as u32, &file_entry.track_title),
+                                        (ColumnsSameMusic::Artist as u32, &file_entry.track_artist),
                                         (ColumnsSameMusic::Year as u32, &file_entry.year.to_string()),
+                                        (ColumnsSameMusic::Genre as u32, &file_entry.genre),
+                                        (ColumnsSameMusic::Bitrate as u32, &(format!("{} kbps", file_entry.bitrate))),
+                                        (ColumnsSameMusic::BitrateAsNumber as u32, &(file_entry.bitrate)),
+                                        (ColumnsSameMusic::Length as u32, &file_entry.length),
                                         (
                                             ColumnsSameMusic::Modification as u32,
                                             &(NaiveDateTime::from_timestamp(file_entry.modified_date as i64, 0).to_string()),
@@ -1498,6 +1507,73 @@ pub fn connect_compute_results(gui_data: &GuiData, glib_stop_receiver: Receiver<
                     }
                 }
             }
+            Message::BadExtensions(be) => {
+                if be.get_stopped_search() {
+                    entry_info.set_text(&flg!("compute_stopped_by_user"));
+                } else {
+                    let information = be.get_information();
+                    let text_messages = be.get_text_messages();
+
+                    let bad_extensions_number: usize = information.number_of_files_with_bad_extension;
+                    entry_info.set_text(
+                        flg!(
+                            "compute_found_bad_extensions",
+                            generate_translation_hashmap(vec![("number_files", bad_extensions_number.to_string()),])
+                        )
+                        .as_str(),
+                    );
+
+                    // Create GUI
+                    {
+                        let list_store = get_list_store(&tree_view_bad_extensions);
+
+                        let vector = be.get_bad_extensions_files();
+
+                        // Sort
+                        let mut vector = vector.clone();
+                        vector.sort_by_key(|e| {
+                            let t = split_path(e.path.as_path());
+                            (t.0, t.1)
+                        });
+
+                        for file_entry in vector {
+                            let (directory, file) = split_path(&file_entry.path);
+                            let values: [(u32, &dyn ToValue); 7] = [
+                                (ColumnsBadExtensions::SelectionButton as u32, &false),
+                                (ColumnsBadExtensions::Name as u32, &file),
+                                (ColumnsBadExtensions::Path as u32, &directory),
+                                (ColumnsBadExtensions::CurrentExtension as u32, &file_entry.current_extension),
+                                (ColumnsBadExtensions::ValidExtensions as u32, &file_entry.proper_extensions),
+                                (
+                                    ColumnsBadExtensions::Modification as u32,
+                                    &(NaiveDateTime::from_timestamp(file_entry.modified_date as i64, 0).to_string()),
+                                ),
+                                (ColumnsBadExtensions::ModificationAsSecs as u32, &(file_entry.modified_date as i64)),
+                            ];
+                            list_store.set(&list_store.append(), &values);
+                        }
+                        print_text_messages_to_text_view(text_messages, &text_view_errors);
+                    }
+
+                    // Set state
+                    {
+                        *shared_bad_extensions_state.borrow_mut() = be;
+
+                        set_specific_buttons_as_active(
+                            &shared_buttons,
+                            &NotebookMainEnum::Temporary,
+                            &[BottomButtonsEnum::Save, BottomButtonsEnum::Delete, BottomButtonsEnum::Select, BottomButtonsEnum::Move],
+                            bad_extensions_number > 0,
+                        );
+
+                        set_buttons(
+                            &mut *shared_buttons.borrow_mut().get_mut(&NotebookMainEnum::Temporary).unwrap(),
+                            &buttons_array,
+                            &buttons_names,
+                        );
+                    }
+                }
+            }
         }
         // Returning false here would close the receiver and have senders fail
         glib::Continue(true)
