@@ -1,22 +1,16 @@
 use crate::flg;
-use czkawka_core::common::get_dynamic_image_from_raw_image;
-use czkawka_core::similar_images::RAW_IMAGE_EXTENSIONS;
+use gdk::gdk_pixbuf::{InterpType, Pixbuf};
 use gtk::prelude::*;
 use gtk::{CheckButton, Image, ListStore, Orientation, ScrolledWindow, TreeIter, TreeModel, TreePath, TreeSelection};
-use image::imageops::FilterType;
-use image::DynamicImage;
 use std::cell::RefCell;
 use std::rc::Rc;
 
 use crate::gui_structs::gui_data::GuiData;
-use crate::help_functions::{
-    count_number_of_groups, get_full_name_from_path_name, get_image_path_temporary, get_max_file_name, resize_dynamic_image_dimension, NotebookObject, HEADER_ROW_COLOR,
-    NOTEBOOKS_INFOS,
-};
+use crate::help_functions::{count_number_of_groups, get_full_name_from_path_name, get_max_file_name, resize_pixbuf_dimension, NotebookObject, HEADER_ROW_COLOR, NOTEBOOKS_INFOS};
 use crate::localizer_core::generate_translation_hashmap;
 
-const BIG_PREVIEW_SIZE: u32 = 600;
-const SMALL_PREVIEW_SIZE: u32 = 100;
+const BIG_PREVIEW_SIZE: i32 = 600;
+const SMALL_PREVIEW_SIZE: i32 = 100;
 
 pub fn connect_button_compare(gui_data: &GuiData) {
     let button_compare = gui_data.bottom_buttons.buttons_compare.clone();
@@ -132,13 +126,13 @@ pub fn connect_button_compare(gui_data: &GuiData) {
         let current_group = *shared_current_of_groups.borrow();
         let group_number = *shared_numbers_of_groups.borrow();
 
-        let tree_iter = move_iter(&model, shared_current_path.borrow().as_ref().unwrap(), nb_object.column_color.unwrap(), false);
+        let tree_path = move_iter(&model, shared_current_path.borrow().as_ref().unwrap(), nb_object.column_color.unwrap(), false);
 
         populate_groups_at_start(
             nb_object,
             &model,
             shared_current_path.clone(),
-            tree_iter,
+            tree_path,
             &image_compare_left,
             &image_compare_right,
             current_group,
@@ -345,37 +339,39 @@ fn generate_cache_for_results(vector_with_path: Vec<(String, String, gtk::TreePa
     // For now threads cannot be used because Image and TreeIter cannot be used in threads
     let mut cache_all_images = Vec::new();
     for (full_path, name, tree_path) in vector_with_path {
-        let name_lowercase = name.to_lowercase();
-        let dynamic_image = if RAW_IMAGE_EXTENSIONS.iter().any(|f| name_lowercase.ends_with(f)) {
-            match get_dynamic_image_from_raw_image(&full_path) {
-                Some(t) => t,
-                None => {
-                    println!("Failed to convert rawimage {}", full_path);
-                    DynamicImage::new_rgb8(1, 1)
+        let small_img = gtk::Image::new();
+        let big_img = gtk::Image::new();
+
+        match Pixbuf::from_file(&full_path) {
+            Ok(pixbuf) =>
+            {
+                #[allow(clippy::never_loop)]
+                loop {
+                    let pixbuf_big = match resize_pixbuf_dimension(pixbuf, (BIG_PREVIEW_SIZE, BIG_PREVIEW_SIZE), InterpType::Nearest) {
+                        None => {
+                            println!("Failed to resize image {}.", full_path);
+                            break;
+                        }
+                        Some(pixbuf) => pixbuf,
+                    };
+                    let pixbuf_small = match resize_pixbuf_dimension(pixbuf_big.clone(), (SMALL_PREVIEW_SIZE, SMALL_PREVIEW_SIZE), InterpType::Nearest) {
+                        None => {
+                            println!("Failed to resize image {}.", full_path);
+                            break;
+                        }
+                        Some(pixbuf) => pixbuf,
+                    };
+
+                    big_img.set_pixbuf(Some(&pixbuf_big));
+                    small_img.set_pixbuf(Some(&pixbuf_small));
+                    break;
                 }
             }
-        } else {
-            match image::open(&full_path) {
-                Ok(t) => t,
-                Err(_) => {
-                    println!("Failed to open image {}", full_path);
-                    DynamicImage::new_rgb8(1, 1)
-                }
+            Err(e) => {
+                println!("Failed to open image {}, reason {}", full_path, e);
             }
         };
 
-        let big_thumbnail = resize_dynamic_image_dimension(dynamic_image, (BIG_PREVIEW_SIZE, BIG_PREVIEW_SIZE), &FilterType::Triangle);
-        let big_path = get_image_path_temporary("roman", 1, "jpg");
-        let _ = big_thumbnail.save(&big_path);
-        let big_img = gtk::Image::new();
-        big_img.set_from_file(big_path);
-
-        let small_thumbnail = resize_dynamic_image_dimension(big_thumbnail, (SMALL_PREVIEW_SIZE, SMALL_PREVIEW_SIZE), &FilterType::Triangle);
-        let small_path = get_image_path_temporary("roman", 1, "jpg");
-        let _ = small_thumbnail.save(&small_path);
-        let small_img = gtk::Image::new();
-        small_img.set_from_file(small_path);
-
         cache_all_images.push((full_path, name, big_img, small_img, tree_path));
     }
     cache_all_images
@@ -430,6 +426,7 @@ fn get_all_path(model: &TreeModel, current_path: &TreePath, column_color: i32, c
 /// Moves iterator to previous/next header
 fn move_iter(model: &gtk::TreeModel, tree_path: &TreePath, column_color: i32, go_next: bool) -> TreePath {
     let tree_iter = model.iter(tree_path).unwrap();
+
     assert_eq!(model.value(&tree_iter, column_color).get::<String>().unwrap(), HEADER_ROW_COLOR);
 
     if go_next {
@@ -579,8 +576,8 @@ fn get_current_group_and_iter_from_selection(model: &TreeModel, selection: TreeS
     let selected_records = selection.selected_rows().0;
 
     let iter = model.iter_first().unwrap(); // Checking that treeview is not empty should be done before
-    header_clone = iter.clone(); // if nothing selected, use first group
-    possible_header = iter.clone(); // if nothing selected, use first group
+    header_clone = iter; // if nothing selected, use first group
+    possible_header = iter; // if nothing selected, use first group
     assert_eq!(model.value(&iter, column_color).get::<String>().unwrap(), HEADER_ROW_COLOR); // First element should be header
 
     if !selected_records.is_empty() {
@@ -592,11 +589,11 @@ fn get_current_group_and_iter_from_selection(model: &TreeModel, selection: TreeS
 
             if model.value(&iter, column_color).get::<String>().unwrap() == HEADER_ROW_COLOR {
                 possible_group += 1;
-                possible_header = iter.clone();
+                possible_header = iter;
             }
 
             if model.path(&iter).unwrap() == first_selected_record {
-                header_clone = possible_header.clone();
+                header_clone = possible_header;
                 current_group = possible_group;
             }
         }
