@@ -5,6 +5,7 @@ use std::thread;
 use glib::Sender;
 use gtk::prelude::*;
 
+use czkawka_core::bad_extensions::BadExtensions;
 use czkawka_core::big_file::BigFile;
 use czkawka_core::broken_files::BrokenFiles;
 use czkawka_core::common_dir_traversal;
@@ -41,6 +42,7 @@ pub fn connect_button_search(
     futures_sender_temporary: futures::channel::mpsc::UnboundedSender<temporary::ProgressData>,
     futures_sender_invalid_symlinks: futures::channel::mpsc::UnboundedSender<common_dir_traversal::ProgressData>,
     futures_sender_broken_files: futures::channel::mpsc::UnboundedSender<broken_files::ProgressData>,
+    futures_sender_bad_extensions: futures::channel::mpsc::UnboundedSender<common_dir_traversal::ProgressData>,
 ) {
     let combo_box_image_hash_size = gui_data.main_notebook.combo_box_image_hash_size.clone();
     let combo_box_image_hash_algorithm = gui_data.main_notebook.combo_box_image_hash_algorithm.clone();
@@ -53,11 +55,13 @@ pub fn connect_button_search(
     let buttons_names = gui_data.bottom_buttons.buttons_names;
     let buttons_search_clone = gui_data.bottom_buttons.buttons_search.clone();
     let check_button_duplicates_use_prehash_cache = gui_data.settings.check_button_duplicates_use_prehash_cache.clone();
-    let check_button_music_album_artist: gtk::CheckButton = gui_data.main_notebook.check_button_music_album_artist.clone();
-    let check_button_music_album_title: gtk::CheckButton = gui_data.main_notebook.check_button_music_album_title.clone();
+    let check_button_duplicate_case_sensitive_name: gtk::CheckButton = gui_data.main_notebook.check_button_duplicate_case_sensitive_name.clone();
     let check_button_music_artist: gtk::CheckButton = gui_data.main_notebook.check_button_music_artist.clone();
     let check_button_music_title: gtk::CheckButton = gui_data.main_notebook.check_button_music_title.clone();
     let check_button_music_year: gtk::CheckButton = gui_data.main_notebook.check_button_music_year.clone();
+    let check_button_music_genre: gtk::CheckButton = gui_data.main_notebook.check_button_music_genre.clone();
+    let check_button_music_length: gtk::CheckButton = gui_data.main_notebook.check_button_music_length.clone();
+    let check_button_music_bitrate: gtk::CheckButton = gui_data.main_notebook.check_button_music_bitrate.clone();
     let check_button_recursive = gui_data.upper_notebook.check_button_recursive.clone();
     let check_button_settings_duplicates_delete_outdated_cache = gui_data.settings.check_button_settings_duplicates_delete_outdated_cache.clone();
     let check_button_settings_hide_hard_links = gui_data.settings.check_button_settings_hide_hard_links.clone();
@@ -97,6 +101,7 @@ pub fn connect_button_search(
     let tree_view_similar_images_finder = gui_data.main_notebook.tree_view_similar_images_finder.clone();
     let tree_view_similar_videos_finder = gui_data.main_notebook.tree_view_similar_videos_finder.clone();
     let tree_view_temporary_files_finder = gui_data.main_notebook.tree_view_temporary_files_finder.clone();
+    let tree_view_bad_extensions = gui_data.main_notebook.tree_view_bad_extensions.clone();
     let window_progress = gui_data.progress_window.window_progress.clone();
     let entry_info = gui_data.entry_info.clone();
     let button_settings = gui_data.header.button_settings.clone();
@@ -155,6 +160,8 @@ pub fn connect_button_search(
 
         let glib_stop_sender = glib_stop_sender.clone();
         let stop_receiver = stop_receiver.clone();
+        // Consume any stale stop messages.
+        stop_receiver.try_iter().for_each(|_| ());
 
         match to_notebook_main_enum(notebook_main.current_page().unwrap()) {
             NotebookMainEnum::Duplicate => {
@@ -175,6 +182,8 @@ pub fn connect_button_search(
                 let use_prehash_cache = check_button_duplicates_use_prehash_cache.is_active();
                 let minimal_prehash_cache_file_size = entry_settings_prehash_cache_file_minimal_size.text().as_str().parse::<u64>().unwrap_or(0);
 
+                let case_sensitive_name_comparison = check_button_duplicate_case_sensitive_name.is_active();
+
                 let delete_outdated_cache = check_button_settings_duplicates_delete_outdated_cache.is_active();
 
                 let futures_sender_duplicate_files = futures_sender_duplicate_files.clone();
@@ -197,6 +206,7 @@ pub fn connect_button_search(
                     df.set_use_cache(use_cache);
                     df.set_use_prehash_cache(use_prehash_cache);
                     df.set_delete_outdated_cache(delete_outdated_cache);
+                    df.set_case_sensitive_name_comparison(case_sensitive_name_comparison);
                     df.find_duplicates(Some(&stop_receiver), Some(&futures_sender_duplicate_files));
                     let _ = glib_stop_sender.send(Message::Duplicates(df));
                 });
@@ -383,20 +393,23 @@ pub fn connect_button_search(
                 let mut music_similarity: MusicSimilarity = MusicSimilarity::NONE;
 
                 if check_button_music_title.is_active() {
-                    music_similarity |= MusicSimilarity::TITLE;
+                    music_similarity |= MusicSimilarity::TRACK_TITLE;
                 }
                 if check_button_music_artist.is_active() {
-                    music_similarity |= MusicSimilarity::ARTIST;
-                }
-                if check_button_music_album_title.is_active() {
-                    music_similarity |= MusicSimilarity::ALBUM_TITLE;
-                }
-                if check_button_music_album_artist.is_active() {
-                    music_similarity |= MusicSimilarity::ALBUM_ARTIST;
+                    music_similarity |= MusicSimilarity::TRACK_ARTIST;
                 }
                 if check_button_music_year.is_active() {
                     music_similarity |= MusicSimilarity::YEAR;
                 }
+                if check_button_music_bitrate.is_active() {
+                    music_similarity |= MusicSimilarity::BITRATE;
+                }
+                if check_button_music_genre.is_active() {
+                    music_similarity |= MusicSimilarity::GENRE;
+                }
+                if check_button_music_length.is_active() {
+                    music_similarity |= MusicSimilarity::LENGTH;
+                }
 
                 if music_similarity != MusicSimilarity::NONE {
                     let futures_sender_same_music = futures_sender_same_music.clone();
@@ -472,6 +485,29 @@ pub fn connect_button_search(
                     let _ = glib_stop_sender.send(Message::BrokenFiles(br));
                 });
             }
+            NotebookMainEnum::BadExtensions => {
+                label_stage.show();
+                grid_progress_stages.show_all();
+                window_progress.resize(1, 1);
+
+                get_list_store(&tree_view_bad_extensions).clear();
+
+                let futures_sender_bad_extensions = futures_sender_bad_extensions.clone();
+                // Find Similar music
+                thread::spawn(move || {
+                    let mut be = BadExtensions::new();
+
+                    be.set_included_directory(included_directories);
+                    be.set_excluded_directory(excluded_directories);
+                    be.set_excluded_items(excluded_items);
+                    be.set_minimal_file_size(minimal_file_size);
+                    be.set_maximal_file_size(maximal_file_size);
+                    be.set_allowed_extensions(allowed_extensions);
+                    be.set_recursive_search(recursive_search);
+                    be.find_bad_extensions_files(Some(&stop_receiver), Some(&futures_sender_bad_extensions));
+                    let _ = glib_stop_sender.send(Message::BadExtensions(be));
+                });
+            }
         }
 
         // Show progress dialog
