@@ -112,7 +112,7 @@ fn popover_all_except_oldest_newest(
                     }
                     break;
                 }
-                tree_iter_array.push(iter.clone());
+                tree_iter_array.push(iter);
                 let modification = model.value(&iter, column_modification_as_secs).get::<u64>().unwrap();
                 let current_file_length = model.value(&iter, column_file_name).get::<String>().unwrap().len();
                 if except_oldest {
@@ -187,7 +187,7 @@ fn popover_one_oldest_newest(
                     }
                     break;
                 }
-                tree_iter_array.push(iter.clone());
+                tree_iter_array.push(iter);
                 let modification = model.value(&iter, column_modification_as_secs).get::<u64>().unwrap();
                 let current_file_length = model.value(&iter, column_file_name).get::<String>().unwrap().len();
                 if check_oldest {
@@ -258,6 +258,9 @@ fn popover_custom_select_unselect(
         let check_button_name = gtk::CheckButton::builder().label(&flg!("popover_custom_regex_name_label")).build();
         let check_button_rust_regex = gtk::CheckButton::builder().label(&flg!("popover_custom_regex_regex_label")).build();
 
+        let check_button_case_sensitive = gtk::CheckButton::builder().label(&flg!("popover_custom_case_sensitive_check_button")).build();
+        check_button_case_sensitive.set_active(false);
+
         let check_button_select_not_all_results = gtk::CheckButton::builder().label(&flg!("popover_custom_all_in_group_label")).build();
         check_button_select_not_all_results.set_active(true);
 
@@ -279,6 +282,7 @@ fn popover_custom_select_unselect(
             check_button_rust_regex.set_tooltip_text(Some(&flg!("popover_custom_regex_check_button_entry_tooltip")));
             entry_rust_regex.set_tooltip_text(Some(&flg!("popover_custom_regex_check_button_entry_tooltip")));
 
+            check_button_case_sensitive.set_tooltip_text(Some(&flg!("popover_custom_case_sensitive_check_button_tooltip")));
             check_button_select_not_all_results.set_tooltip_text(Some(&flg!("popover_custom_not_all_check_button_tooltip")));
         }
         {
@@ -347,8 +351,10 @@ fn popover_custom_select_unselect(
 
             grid.attach(&label_regex_valid, 0, 4, 2, 1);
 
+            grid.attach(&check_button_case_sensitive, 0, 5, 2, 1);
+
             if select_things {
-                grid.attach(&check_button_select_not_all_results, 0, 5, 2, 1);
+                grid.attach(&check_button_select_not_all_results, 0, 6, 2, 1);
             }
 
             let box_widget = get_dialog_box_child(&dialog);
@@ -359,25 +365,26 @@ fn popover_custom_select_unselect(
 
         let tree_view = tree_view.clone();
         dialog.connect_response(move |confirmation_dialog_select_unselect, response_type| {
-            let name_widcard = entry_name.text().trim().to_string();
-            let path_widcard = entry_path.text().trim().to_string();
-            let regex_widcard = entry_rust_regex.text().trim().to_string();
+            let name_wildcard = entry_name.text().trim().to_string();
+            let path_wildcard = entry_path.text().trim().to_string();
+            let regex_wildcard = entry_rust_regex.text().trim().to_string();
 
             #[cfg(target_family = "windows")]
-            let name_widcard = name_widcard.replace("/", "\\");
+            let name_wildcard = name_wildcard.replace("/", "\\");
             #[cfg(target_family = "windows")]
-            let path_widcard = name_widcard.replace("/", "\\");
+            let path_wildcard = path_wildcard.replace("/", "\\");
 
             if response_type == gtk::ResponseType::Ok {
                 let check_path = check_button_path.is_active();
                 let check_name = check_button_name.is_active();
                 let check_regex = check_button_rust_regex.is_active();
+                let case_sensitive = check_button_case_sensitive.is_active();
 
                 let check_all_selected = check_button_select_not_all_results.is_active();
 
                 if check_button_path.is_active() || check_button_name.is_active() || check_button_rust_regex.is_active() {
                     let compiled_regex = match check_regex {
-                        true => match Regex::new(&regex_widcard) {
+                        true => match Regex::new(&regex_wildcard) {
                             Ok(t) => t,
                             Err(_) => {
                                 eprintln!("What? Regex should compile properly.");
@@ -441,23 +448,41 @@ fn popover_custom_select_unselect(
                         if check_regex && compiled_regex.find(&path_and_name).is_some() {
                             need_to_change_thing = true;
                         } else {
-                            if check_name && Common::regex_check(&name_widcard, &name) {
-                                need_to_change_thing = true;
+                            if check_name {
+                                if case_sensitive {
+                                    if Common::regex_check(&name_wildcard, &name) {
+                                        need_to_change_thing = true;
+                                    }
+                                } else {
+                                    if Common::regex_check(&name_wildcard.to_lowercase(), &name.to_lowercase()) {
+                                        need_to_change_thing = true;
+                                    }
+                                }
                             }
-                            if check_path && Common::regex_check(&path_widcard, &path) {
-                                need_to_change_thing = true;
+                            if check_path {
+                                if case_sensitive {
+                                    if Common::regex_check(&path_wildcard, &path) {
+                                        need_to_change_thing = true;
+                                    }
+                                } else {
+                                    if Common::regex_check(&path_wildcard.to_lowercase(), &path.to_lowercase()) {
+                                        need_to_change_thing = true;
+                                    }
+                                }
                             }
                         }
 
-                        if need_to_change_thing {
-                            if select_things {
-                                if is_selected {
-                                    number_of_already_selected_things += 1;
-                                } else {
-                                    vec_of_iters.push(iter.clone());
-                                }
+                        if select_things {
+                            if is_selected {
+                                number_of_already_selected_things += 1;
                             } else {
-                                vec_of_iters.push(iter.clone());
+                                if need_to_change_thing {
+                                    vec_of_iters.push(iter);
+                                }
+                            }
+                        } else {
+                            if need_to_change_thing {
+                                vec_of_iters.push(iter);
                             }
                         }
 
@@ -518,7 +543,7 @@ fn popover_all_except_biggest_smallest(
                     }
                     break;
                 }
-                tree_iter_array.push(iter.clone());
+                tree_iter_array.push(iter);
                 let size_as_bytes = model.value(&iter, column_size_as_bytes).get::<u64>().unwrap();
 
                 // If dimension exists, then needs to be checked images
