@@ -23,6 +23,7 @@ pub struct GuiMainNotebook {
     pub scrolled_window_same_music_finder: gtk::ScrolledWindow,
     pub scrolled_window_invalid_symlinks: gtk::ScrolledWindow,
     pub scrolled_window_broken_files: gtk::ScrolledWindow,
+    pub scrolled_window_bad_extensions: gtk::ScrolledWindow,
 
     pub tree_view_duplicate_finder: gtk::TreeView,
     pub tree_view_empty_folder_finder: gtk::TreeView,
@@ -34,6 +35,7 @@ pub struct GuiMainNotebook {
     pub tree_view_same_music_finder: gtk::TreeView,
     pub tree_view_invalid_symlinks: gtk::TreeView,
     pub tree_view_broken_files: gtk::TreeView,
+    pub tree_view_bad_extensions: gtk::TreeView,
 
     // TODO, in GTK4 this can be changed to e.g. add_controller which is not 100% compatible with this  - https://discourse.gnome.org/t/how-to-convert-code-to-use-eventcontrollerkey/8198/2
     pub evk_tree_view_duplicate_finder: gtk::EventControllerKey,
@@ -46,6 +48,7 @@ pub struct GuiMainNotebook {
     pub evk_tree_view_same_music_finder: gtk::EventControllerKey,
     pub evk_tree_view_invalid_symlinks: gtk::EventControllerKey,
     pub evk_tree_view_broken_files: gtk::EventControllerKey,
+    pub evk_tree_view_bad_extensions: gtk::EventControllerKey,
 
     // pub gc_tree_view_duplicate_finder: gtk4::GestureClick,
     // pub gc_tree_view_empty_folder_finder: gtk::GestureClick,
@@ -57,6 +60,7 @@ pub struct GuiMainNotebook {
     // pub gc_tree_view_same_music_finder: gtk::GestureClick,
     // pub gc_tree_view_invalid_symlinks: gtk::GestureClick,
     // pub gc_tree_view_broken_files: gtk::GestureClick,
+    // pub gc_tree_view_bad_extensions: gtk::GestureClick,
 
     // General
 
@@ -65,6 +69,7 @@ pub struct GuiMainNotebook {
     pub combo_box_duplicate_hash_type: gtk::ComboBoxText,
     pub label_duplicate_check_method: gtk::Label,
     pub label_duplicate_hash_type: gtk::Label,
+    pub check_button_duplicate_case_sensitive_name: gtk::CheckButton,
 
     pub image_preview_duplicates: gtk::Image,
 
@@ -104,9 +109,10 @@ pub struct GuiMainNotebook {
     // Music
     pub check_button_music_title: gtk::CheckButton,
     pub check_button_music_artist: gtk::CheckButton,
-    pub check_button_music_album_title: gtk::CheckButton,
-    pub check_button_music_album_artist: gtk::CheckButton,
     pub check_button_music_year: gtk::CheckButton,
+    pub check_button_music_bitrate: gtk::CheckButton,
+    pub check_button_music_genre: gtk::CheckButton,
+    pub check_button_music_length: gtk::CheckButton,
     pub check_button_music_approximate_comparison: gtk::CheckButton,
 }
 
@@ -124,6 +130,7 @@ impl GuiMainNotebook {
         let scrolled_window_same_music_finder: gtk::ScrolledWindow = builder.object("scrolled_window_same_music_finder").unwrap();
         let scrolled_window_invalid_symlinks: gtk::ScrolledWindow = builder.object("scrolled_window_invalid_symlinks").unwrap();
         let scrolled_window_broken_files: gtk::ScrolledWindow = builder.object("scrolled_window_broken_files").unwrap();
+        let scrolled_window_bad_extensions: gtk::ScrolledWindow = builder.object("scrolled_window_bad_extensions").unwrap();
 
         let tree_view_duplicate_finder: gtk::TreeView = TreeView::new();
         tree_view_duplicate_finder.set_widget_name("PIERD");
@@ -136,6 +143,7 @@ impl GuiMainNotebook {
         let tree_view_same_music_finder: gtk::TreeView = TreeView::new();
         let tree_view_invalid_symlinks: gtk::TreeView = TreeView::new();
         let tree_view_broken_files: gtk::TreeView = TreeView::new();
+        let tree_view_bad_extensions: gtk::TreeView = TreeView::new();
 
         let evk_tree_view_duplicate_finder: gtk::EventControllerKey = EventControllerKey::new(&tree_view_duplicate_finder);
         let evk_tree_view_empty_folder_finder: gtk::EventControllerKey = EventControllerKey::new(&tree_view_empty_folder_finder);
@@ -147,6 +155,7 @@ impl GuiMainNotebook {
         let evk_tree_view_same_music_finder: gtk::EventControllerKey = EventControllerKey::new(&tree_view_same_music_finder);
         let evk_tree_view_invalid_symlinks: gtk::EventControllerKey = EventControllerKey::new(&tree_view_invalid_symlinks);
         let evk_tree_view_broken_files: gtk::EventControllerKey = EventControllerKey::new(&tree_view_broken_files);
+        let evk_tree_view_bad_extensions: gtk::EventControllerKey = EventControllerKey::new(&tree_view_bad_extensions);
 
         // TODO GTK 4
         // let evk_tree_view_duplicate_finder: gtk4::EventControllerKey = EventControllerKey::new();
@@ -169,6 +178,8 @@ impl GuiMainNotebook {
         // tree_view_invalid_symlinks.add_controller(&evk_tree_view_invalid_symlinks);
         // let evk_tree_view_broken_files: gtk4::EventControllerKey = EventControllerKey::new();
         // tree_view_broken_files.add_controller(&evk_tree_view_broken_files);
+        // let evk_tree_view_bad_extensions: gtk4::EventControllerKey = EventControllerKey::new();
+        // tree_view_bad_extensions.add_controller(&evk_tree_view_bad_extensions);
 
         // let gc_tree_view_duplicate_finder: gtk4::GestureClick = GestureClick::new();
         // tree_view_duplicate_finder.add_controller(&gc_tree_view_duplicate_finder);
@@ -190,6 +201,8 @@ impl GuiMainNotebook {
         // tree_view_invalid_symlinks.add_controller(&gc_tree_view_invalid_symlinks);
         // let gc_tree_view_broken_files: gtk4::GestureClick = GestureClick::new();
         // tree_view_broken_files.add_controller(&gc_tree_view_broken_files);
+        // let gc_tree_view_bad_extensions: gtk4::GestureClick = GestureClick::new();
+        // tree_view_bad_extensions.add_controller(&gc_tree_view_bad_extensions);
 
         let combo_box_duplicate_check_method: gtk::ComboBoxText = builder.object("combo_box_duplicate_check_method").unwrap();
         let combo_box_duplicate_hash_type: gtk::ComboBoxText = builder.object("combo_box_duplicate_hash_type").unwrap();
@@ -197,11 +210,13 @@ impl GuiMainNotebook {
         let entry_big_files_number: gtk::Entry = builder.object("entry_big_files_number").unwrap();
 
         //// Check Buttons
+        let check_button_duplicate_case_sensitive_name: gtk::CheckButton = builder.object("check_button_duplicate_case_sensitive_name").unwrap();
         let check_button_music_title: gtk::CheckButton = builder.object("check_button_music_title").unwrap();
         let check_button_music_artist: gtk::CheckButton = builder.object("check_button_music_artist").unwrap();
-        let check_button_music_album_title: gtk::CheckButton = builder.object("check_button_music_album_title").unwrap();
-        let check_button_music_album_artist: gtk::CheckButton = builder.object("check_button_music_album_artist").unwrap();
         let check_button_music_year: gtk::CheckButton = builder.object("check_button_music_year").unwrap();
+        let check_button_music_bitrate: gtk::CheckButton = builder.object("check_button_music_bitrate").unwrap();
+        let check_button_music_genre: gtk::CheckButton = builder.object("check_button_music_genre").unwrap();
+        let check_button_music_length: gtk::CheckButton = builder.object("check_button_music_length").unwrap();
         let check_button_music_approximate_comparison: gtk::CheckButton = builder.object("check_button_music_approximate_comparison").unwrap();
 
         //// Radio Buttons
@@ -247,6 +262,7 @@ impl GuiMainNotebook {
             scrolled_window_same_music_finder,
             scrolled_window_invalid_symlinks,
             scrolled_window_broken_files,
+            scrolled_window_bad_extensions,
             tree_view_duplicate_finder,
             tree_view_empty_folder_finder,
             tree_view_empty_files_finder,
@@ -257,6 +273,7 @@ impl GuiMainNotebook {
             tree_view_same_music_finder,
             tree_view_invalid_symlinks,
             tree_view_broken_files,
+            tree_view_bad_extensions,
             evk_tree_view_duplicate_finder,
             evk_tree_view_empty_folder_finder,
             evk_tree_view_empty_files_finder,
@@ -270,9 +287,10 @@ impl GuiMainNotebook {
             entry_big_files_number,
             check_button_music_title,
             check_button_music_artist,
-            check_button_music_album_title,
-            check_button_music_album_artist,
             check_button_music_year,
+            check_button_music_bitrate,
+            check_button_music_genre,
+            check_button_music_length,
             check_button_music_approximate_comparison,
             scale_similarity_similar_images,
             scale_similarity_similar_videos,
@@ -298,6 +316,8 @@ impl GuiMainNotebook {
             combo_box_image_hash_size,
             check_button_video_ignore_same_size,
             check_button_image_fast_compare,
+            check_button_duplicate_case_sensitive_name,
+            evk_tree_view_bad_extensions,
         }
     }
 
@@ -313,15 +333,18 @@ impl GuiMainNotebook {
             self.tree_view_same_music_finder.clone(),
             self.tree_view_invalid_symlinks.clone(),
             self.tree_view_broken_files.clone(),
+            self.tree_view_bad_extensions.clone(),
         ]
     }
 
     pub fn update_language(&self) {
+        self.check_button_duplicate_case_sensitive_name.set_label(&flg!("duplicate_case_sensitive_name"));
         self.check_button_music_title.set_label(&flg!("music_title_checkbox"));
         self.check_button_music_artist.set_label(&flg!("music_artist_checkbox"));
-        self.check_button_music_album_title.set_label(&flg!("music_album_title_checkbox"));
-        self.check_button_music_album_artist.set_label(&flg!("music_album_artist_checkbox"));
         self.check_button_music_year.set_label(&flg!("music_year_checkbox"));
+        self.check_button_music_bitrate.set_label(&flg!("music_bitrate_checkbox"));
+        self.check_button_music_genre.set_label(&flg!("music_genre_checkbox"));
+        self.check_button_music_length.set_label(&flg!("music_length_checkbox"));
         self.check_button_music_approximate_comparison.set_label(&flg!("music_comparison_checkbox"));
 
         self.check_button_music_approximate_comparison
@@ -343,6 +366,8 @@ impl GuiMainNotebook {
         self.combo_box_duplicate_check_method.set_tooltip_text(Some(&flg!("duplicate_check_method_tooltip")));
         self.label_duplicate_hash_type.set_tooltip_text(Some(&flg!("duplicate_hash_type_tooltip")));
         self.combo_box_duplicate_hash_type.set_tooltip_text(Some(&flg!("duplicate_hash_type_tooltip")));
+        self.check_button_duplicate_case_sensitive_name
+            .set_tooltip_text(Some(&flg!("duplicate_case_sensitive_name_tooltip")));
 
         self.combo_box_image_hash_size.set_tooltip_text(Some(&flg!("image_hash_size_tooltip")));
         self.label_image_hash_size.set_tooltip_text(Some(&flg!("image_hash_size_tooltip")));
@@ -405,6 +430,7 @@ impl GuiMainNotebook {
             (NotebookMainEnum::SameMusic as usize, flg!("main_notebook_same_music")),
             (NotebookMainEnum::Symlinks as usize, flg!("main_notebook_symlinks")),
             (NotebookMainEnum::BrokenFiles as usize, flg!("main_notebook_broken_files")),
+            (NotebookMainEnum::BadExtensions as usize, flg!("main_notebook_bad_extensions")),
         ] {
             self.notebook_main
                 .tab_label(&vec_children[main_enum])
@@ -460,12 +486,13 @@ impl GuiMainNotebook {
             vec![
                 flg!("main_tree_view_column_size"),
                 flg!("main_tree_view_column_file_name"),
-                flg!("main_tree_view_column_path"),
                 flg!("main_tree_view_column_title"),
                 flg!("main_tree_view_column_artist"),
                 flg!("main_tree_view_column_year"),
-                flg!("main_tree_view_column_album_title"),
-                flg!("main_tree_view_column_album_artist"),
+                flg!("main_tree_view_column_bitrate"),
+                flg!("main_tree_view_column_length"),
+                flg!("main_tree_view_column_genre"),
+                flg!("main_tree_view_column_path"),
                 flg!("main_tree_view_column_modification"),
             ], // Music Dupliactes
             vec![
@@ -481,6 +508,13 @@ impl GuiMainNotebook {
                 flg!("main_tree_view_column_type_of_error"),
                 flg!("main_tree_view_column_modification"),
             ], // Broken Files
+            vec![
+                flg!("main_tree_view_column_file_name"),
+                flg!("main_tree_view_column_path"),
+                flg!("main_tree_view_column_current_extension"),
+                flg!("main_tree_view_column_proper_extensions"),
+                flg!("main_tree_view_column_modification"),
+            ], // Broken Files
         ];
 
         for (notebook_index, tree_view) in self.get_main_tree_views().iter().enumerate() {
