@@ -1,13 +1,11 @@
-use directories_next::ProjectDirs;
+use gdk::gdk_pixbuf::{InterpType, Pixbuf};
 use std::cmp::Ordering;
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
 
+use czkawka_core::bad_extensions::BadExtensions;
 use gtk::prelude::*;
-use gtk::{ListStore, TextView, TreeView, Widget};
-use image::imageops::FilterType;
-use image::DynamicImage;
-use image::GenericImageView;
+use gtk::{Bin, ListStore, TextView, TreeView, Widget};
 
 use crate::flg;
 use czkawka_core::big_file::BigFile;
@@ -41,6 +39,8 @@ pub const KEY_SPACE: u32 = 65;
 // pub const KEY_HOME: u32 = 115;
 // pub const KEY_END: u32 = 110;
 
+pub const CHECK_GTK_EVENTS_INTERVAL: usize = 100;
+
 #[derive(Eq, PartialEq)]
 pub enum PopoverTypes {
     All,
@@ -208,6 +208,19 @@ pub static NOTEBOOKS_INFOS: [NotebookObject; NUMBER_OF_NOTEBOOK_MAIN_TABS] = [
         column_size_as_bytes: None,
         column_modification_as_secs: None,
     },
+    NotebookObject {
+        notebook_type: NotebookMainEnum::BadExtensions,
+        available_modes: [PopoverTypes::All, PopoverTypes::Reverse, PopoverTypes::Custom, PopoverTypes::None, PopoverTypes::None],
+        column_activatable_button: None,
+        column_path: ColumnsBadExtensions::Path as i32,
+        column_name: ColumnsBadExtensions::Name as i32,
+        column_selection: ColumnsBadExtensions::SelectionButton as i32,
+        column_color: None,
+        column_dimensions: None,
+        column_size: None,
+        column_size_as_bytes: None,
+        column_modification_as_secs: None,
+    },
 ];
 
 pub enum Message {
@@ -221,6 +234,7 @@ pub enum Message {
     SameMusic(SameMusic),
     InvalidSymlinks(InvalidSymlinks),
     BrokenFiles(BrokenFiles),
+    BadExtensions(BadExtensions),
 }
 
 pub enum ColumnsDuplicates {
@@ -318,9 +332,11 @@ pub enum ColumnsSameMusic {
     Path,
     Title,
     Artist,
-    AlbumTitle,
-    AlbumArtist,
     Year,
+    Bitrate,
+    BitrateAsNumber,
+    Length,
+    Genre,
     Modification,
     ModificationAsSecs,
     Color,
@@ -346,6 +362,16 @@ pub enum ColumnsBrokenFiles {
     ModificationAsSecs,
 }
 
+pub enum ColumnsBadExtensions {
+    SelectionButton = 0,
+    Name,
+    Path,
+    CurrentExtension,
+    ValidExtensions,
+    Modification,
+    ModificationAsSecs,
+}
+
 pub const TEXT_COLOR: &str = "#ffffff";
 pub const MAIN_ROW_COLOR: &str = "#343434";
 pub const HEADER_ROW_COLOR: &str = "#272727";
@@ -498,6 +524,7 @@ pub fn get_notebook_enum_from_tree_view(tree_view: &gtk::TreeView) -> NotebookMa
         "tree_view_same_music_finder" => NotebookMainEnum::SameMusic,
         "tree_view_invalid_symlinks" => NotebookMainEnum::Symlinks,
         "tree_view_broken_files" => NotebookMainEnum::BrokenFiles,
+        "tree_view_bad_extensions" => NotebookMainEnum::BadExtensions,
         e => {
             panic!("{}", e)
         }
@@ -547,7 +574,7 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                     panic!("First deleted element, should be a header"); // First element should be header
                 };
 
-                next_iter = current_iter.clone();
+                next_iter = current_iter;
                 if !model.iter_next(&next_iter) {
                     // There is only single header left (H1 -> END) -> (NOTHING)
                     vec_tree_path_to_delete.push(model.path(&current_iter).unwrap());
@@ -557,11 +584,11 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                 if model.value(&next_iter, column_color).get::<String>().unwrap() == HEADER_ROW_COLOR {
                     // There are two headers each others(we remove just first) -> (H1 -> H2) -> (H2)
                     vec_tree_path_to_delete.push(model.path(&current_iter).unwrap());
-                    current_iter = next_iter.clone();
+                    current_iter = next_iter;
                     continue 'main;
                 }
 
-                next_next_iter = next_iter.clone();
+                next_next_iter = next_iter;
                 if !model.iter_next(&next_next_iter) {
                     // There is only one child of header left, so we remove it with header (H1 -> C1 -> END) -> (NOTHING)
                     vec_tree_path_to_delete.push(model.path(&current_iter).unwrap());
@@ -573,7 +600,7 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                     // One child between two headers, we can remove them  (H1 -> C1 -> H2) -> (H2)
                     vec_tree_path_to_delete.push(model.path(&current_iter).unwrap());
                     vec_tree_path_to_delete.push(model.path(&next_iter).unwrap());
-                    current_iter = next_next_iter.clone();
+                    current_iter = next_next_iter;
                     continue 'main;
                 }
 
@@ -584,7 +611,7 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                     }
                     // Move to next header
                     if model.value(&next_next_iter, column_color).get::<String>().unwrap() == HEADER_ROW_COLOR {
-                        current_iter = next_next_iter.clone();
+                        current_iter = next_next_iter;
                         continue 'main;
                     }
                 }
@@ -600,7 +627,7 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                     panic!("First deleted element, should be a header"); // First element should be header
                 };
 
-                next_iter = current_iter.clone();
+                next_iter = current_iter;
                 if !model.iter_next(&next_iter) {
                     // There is only single header left (H1 -> END) -> (NOTHING)
                     vec_tree_path_to_delete.push(model.path(&current_iter).unwrap());
@@ -610,11 +637,11 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                 if model.value(&next_iter, column_color).get::<String>().unwrap() == HEADER_ROW_COLOR {
                     // There are two headers each others(we remove just first) -> (H1 -> H2) -> (H2)
                     vec_tree_path_to_delete.push(model.path(&current_iter).unwrap());
-                    current_iter = next_iter.clone();
+                    current_iter = next_iter;
                     continue 'reference;
                 }
 
-                next_next_iter = next_iter.clone();
+                next_next_iter = next_iter;
                 if !model.iter_next(&next_next_iter) {
                     // There is only one child of header left, so we remove it with header (H1 -> C1 -> END) -> (NOTHING)
                     break 'reference;
@@ -622,7 +649,7 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
 
                 if model.value(&next_next_iter, column_color).get::<String>().unwrap() == HEADER_ROW_COLOR {
                     // One child between two headers, we can remove them  (H1 -> C1 -> H2) -> (H2)
-                    current_iter = next_next_iter.clone();
+                    current_iter = next_next_iter;
                     continue 'reference;
                 }
 
@@ -633,7 +660,7 @@ pub fn clean_invalid_headers(model: &gtk::ListStore, column_color: i32, column_p
                     }
                     // Move to next header
                     if model.value(&next_next_iter, column_color).get::<String>().unwrap() == HEADER_ROW_COLOR {
-                        current_iter = next_next_iter.clone();
+                        current_iter = next_next_iter;
                         continue 'reference;
                     }
                 }
@@ -721,16 +748,16 @@ pub fn count_number_of_groups(tree_view: &TreeView, column_color: i32) -> u32 {
     number_of_selected_groups
 }
 
-pub fn resize_dynamic_image_dimension(img: DynamicImage, requested_size: (u32, u32), filter_type: &FilterType) -> DynamicImage {
-    let current_ratio = img.width() as f32 / img.height() as f32;
+pub fn resize_pixbuf_dimension(pixbuf: Pixbuf, requested_size: (i32, i32), interp_type: InterpType) -> Option<Pixbuf> {
+    let current_ratio = pixbuf.width() as f32 / pixbuf.height() as f32;
     let mut new_size;
     match current_ratio.partial_cmp(&(requested_size.0 as f32 / requested_size.1 as f32)).unwrap() {
         Ordering::Greater => {
-            new_size = (requested_size.0, (img.height() * requested_size.0) / img.width());
+            new_size = (requested_size.0, (pixbuf.height() * requested_size.0) / pixbuf.width());
             new_size = (std::cmp::max(new_size.0, 1), std::cmp::max(new_size.1, 1));
         }
         Ordering::Less => {
-            new_size = ((img.width() * requested_size.1) / img.height(), requested_size.1);
+            new_size = ((pixbuf.width() * requested_size.1) / pixbuf.height(), requested_size.1);
             new_size = (std::cmp::max(new_size.0, 1), std::cmp::max(new_size.1, 1));
         }
         Ordering::Equal => {
@@ -738,17 +765,7 @@ pub fn resize_dynamic_image_dimension(img: DynamicImage, requested_size: (u32, u
             new_size = (std::cmp::max(new_size.0, 1), std::cmp::max(new_size.1, 1));
         }
     }
-    img.resize(new_size.0, new_size.1, *filter_type)
-}
-
-pub fn get_image_path_temporary(file_name: &str, number: u32, extension: &str) -> PathBuf {
-    let path_buf;
-    if let Some(proj_dirs) = ProjectDirs::from("pl", "Qarmin", "Czkawka") {
-        path_buf = PathBuf::from(proj_dirs.cache_dir());
-    } else {
-        path_buf = PathBuf::new().join("/var");
-    }
-    path_buf.join(format!("{}{}.{}", file_name, number, extension))
+    pixbuf.scale_simple(new_size.0, new_size.1, interp_type)
 }
 
 pub fn get_max_file_name(file_name: &str, max_length: usize) -> String {
@@ -775,6 +792,35 @@ pub fn get_custom_label_from_button_with_image(button: &gtk::Bin) -> gtk::Label
     }
     panic!("Button doesn't have proper custom label child");
 }
+pub fn get_custom_image_from_button_with_image(button: &gtk::Bin) -> gtk::Image {
+    let internal_box = match button.child().unwrap().downcast::<gtk::Box>() {
+        Ok(t) => t,
+        Err(wid) => {
+            return wid.downcast::<gtk::Image>().unwrap();
+        }
+    };
+    for child in internal_box.children() {
+        if let Ok(t) = child.downcast::<gtk::Image>() {
+            return t;
+        }
+    }
+    panic!("Button doesn't have proper custom label child");
+}
+
+pub fn handle_gtk_pending_event() -> bool {
+    let have_pending = gtk::events_pending();
+    if have_pending {
+        gtk::main_iteration();
+    }
+    have_pending
+}
+
+pub fn handle_gtk_pending_event_counter(counter: usize) -> bool {
+    if counter > 0 && (counter % CHECK_GTK_EVENTS_INTERVAL) == 0 {
+        return handle_gtk_pending_event();
+    }
+    false
+}
 
 // GTK 4
 // pub fn get_custom_label_from_button_with_image<P: IsA<gtk4::Widget>>(button: &P) -> gtk4::Label {
@@ -817,3 +863,19 @@ pub fn get_custom_label_from_button_with_image(button: &gtk::Bin) -> gtk::Label
 //
 //     return vector;
 // }
+
+const SIZE_OF_ICON: i32 = 18;
+const TYPE_OF_INTERPOLATION: InterpType = InterpType::Tiles;
+
+pub fn set_icon_of_button(button: &gtk::Button, data: &'static [u8]) {
+    let image = get_custom_image_from_button_with_image(&button.clone().upcast::<Bin>());
+    let pixbuf = Pixbuf::from_read(std::io::BufReader::new(data)).unwrap();
+    let pixbuf = pixbuf.scale_simple(SIZE_OF_ICON, SIZE_OF_ICON, TYPE_OF_INTERPOLATION).unwrap();
+    image.set_pixbuf(Some(&pixbuf));
+}
+pub fn set_icon_of_menubutton(button: &gtk::MenuButton, data: &'static [u8]) {
+    let image = get_custom_image_from_button_with_image(&button.clone().upcast::<Bin>());
+    let pixbuf = Pixbuf::from_read(std::io::BufReader::new(data)).unwrap();
+    let pixbuf = pixbuf.scale_simple(SIZE_OF_ICON, SIZE_OF_ICON, TYPE_OF_INTERPOLATION).unwrap();
+    image.set_pixbuf(Some(&pixbuf));
+}
