@@ -1,4 +1,4 @@
-pub const NUMBER_OF_NOTEBOOK_MAIN_TABS: usize = 10;
+pub const NUMBER_OF_NOTEBOOK_MAIN_TABS: usize = 11;
 // pub const NUMBER_OF_NOTEBOOK_UPPER_TABS: usize = 3;
 
 // Needs to be updated when changed order of notebook tabs
@@ -14,6 +14,7 @@ pub enum NotebookMainEnum {
     SameMusic,
     Symlinks,
     BrokenFiles,
+    BadExtensions,
 }
 
 pub fn to_notebook_main_enum(notebook_number: u32) -> NotebookMainEnum {
@@ -28,6 +29,7 @@ pub fn to_notebook_main_enum(notebook_number: u32) -> NotebookMainEnum {
         7 => NotebookMainEnum::SameMusic,
         8 => NotebookMainEnum::Symlinks,
         9 => NotebookMainEnum::BrokenFiles,
+        10 => NotebookMainEnum::BadExtensions,
         _ => panic!("Invalid Notebook Tab"),
     }
 }
@@ -44,6 +46,7 @@ pub fn get_all_main_tabs() -> [NotebookMainEnum; NUMBER_OF_NOTEBOOK_MAIN_TABS] {
         to_notebook_main_enum(7),
         to_notebook_main_enum(8),
         to_notebook_main_enum(9),
+        to_notebook_main_enum(10),
     ]
 }
 
