@@ -1,9 +1,11 @@
 use std::collections::HashMap;
+use std::ffi::OsString;
 use std::fs::File;
 use std::io::{Read, Write};
 use std::path::{Path, PathBuf};
 use std::{env, fs};
 
+use czkawka_core::common_dir_traversal::CheckingMethod;
 use directories_next::ProjectDirs;
 use gtk::prelude::*;
 use gtk::{ComboBoxText, ScrolledWindow, TextView};
@@ -14,11 +16,11 @@ use czkawka_core::similar_images::SIMILAR_VALUES;
 
 use crate::gui_structs::gui_settings::GuiSettings;
 use crate::gui_structs::gui_upper_notebook::GuiUpperNotebook;
+use crate::help_combo_box::DUPLICATES_CHECK_METHOD_COMBO_BOX;
 use crate::help_functions::*;
 use crate::language_functions::{get_language_from_combo_box_text, LANGUAGES_ALL};
 use crate::localizer_core::generate_translation_hashmap;
 
-// TODO organize this better, add specific functions that will allow to load from files specific strings
 const SAVE_FILE_NAME: &str = "czkawka_gui_config_4.txt";
 
 const DEFAULT_SAVE_ON_EXIT: bool = true;
@@ -38,6 +40,7 @@ const DEFAULT_PREHASH_MINIMAL_CACHE_SIZE: &str = "0";
 const DEFAULT_VIDEO_REMOVE_AUTO_OUTDATED_CACHE: bool = false;
 const DEFAULT_IMAGE_REMOVE_AUTO_OUTDATED_CACHE: bool = true;
 const DEFAULT_DUPLICATE_REMOVE_AUTO_OUTDATED_CACHE: bool = true;
+const DEFAULT_DUPLICATE_CASE_SENSITIVE_NAME_CHECKING: bool = false;
 
 const DEFAULT_NUMBER_OF_BIGGEST_FILES: &str = "50";
 const DEFAULT_SIMILAR_IMAGES_SIMILARITY: i32 = 0;
@@ -423,6 +426,7 @@ enum LoadText {
     SimilarVideosSimilarity,
     SimilarVideosIgnoreSameSize,
     MusicApproximateComparison,
+    DuplicateNameCaseSensitive,
 }
 
 fn create_hash_map() -> (HashMap<LoadText, String>, HashMap<String, LoadText>) {
@@ -463,6 +467,7 @@ fn create_hash_map() -> (HashMap<LoadText, String>, HashMap<String, LoadText>) {
         (LoadText::SimilarVideosSimilarity, "similar_videos_similarity"),
         (LoadText::SimilarVideosIgnoreSameSize, "similar_videos_ignore_same_size"),
         (LoadText::MusicApproximateComparison, "music_approximate_comparison"),
+        (LoadText::DuplicateNameCaseSensitive, "duplicate_name_case_sensitive"),
     ];
     let mut hashmap_ls: HashMap<LoadText, String> = Default::default();
     let mut hashmap_sl: HashMap<String, LoadText> = Default::default();
@@ -614,6 +619,10 @@ pub fn save_configuration(manual_execution: bool, upper_notebook: &GuiUpperNoteb
     );
 
     // Other2
+    saving_struct.save_var(
+        hashmap_ls.get(&LoadText::DuplicateNameCaseSensitive).unwrap().to_string(),
+        main_notebook.check_button_duplicate_case_sensitive_name.is_active(),
+    );
     saving_struct.save_var(
         hashmap_ls.get(&LoadText::NumberOfBiggestFiles).unwrap().to_string(),
         main_notebook.entry_big_files_number.text(),
@@ -653,6 +662,7 @@ pub fn load_configuration(
     settings: &GuiSettings,
     text_view_errors: &TextView,
     scrolled_window_errors: &ScrolledWindow,
+    arguments: Vec<OsString>,
 ) {
     let text_view_errors = text_view_errors.clone();
 
@@ -672,8 +682,8 @@ pub fn load_configuration(
     // Loading data from hashmaps
     let (hashmap_ls, _hashmap_sl) = create_hash_map();
 
-    let included_directories: Vec<String> = loaded_entries.get_vector_string(hashmap_ls.get(&LoadText::IncludedDirectories).unwrap().clone(), included_directories);
-    let excluded_directories: Vec<String> = loaded_entries.get_vector_string(hashmap_ls.get(&LoadText::ExcludedDirectories).unwrap().clone(), excluded_directories);
+    let mut included_directories: Vec<String> = loaded_entries.get_vector_string(hashmap_ls.get(&LoadText::IncludedDirectories).unwrap().clone(), included_directories);
+    let mut excluded_directories: Vec<String> = loaded_entries.get_vector_string(hashmap_ls.get(&LoadText::ExcludedDirectories).unwrap().clone(), excluded_directories);
     let excluded_items: String = loaded_entries.get_string(
         hashmap_ls.get(&LoadText::ExcludedItems).unwrap().clone(),
         upper_notebook.entry_excluded_items.text().to_string(),
@@ -735,10 +745,54 @@ pub fn load_configuration(
         hashmap_ls.get(&LoadText::SimilarVideosIgnoreSameSize).unwrap().clone(),
         DEFAULT_SIMILAR_VIDEOS_IGNORE_SAME_SIZE,
     );
+    let check_button_case_sensitive_name = loaded_entries.get_integer(
+        hashmap_ls.get(&LoadText::DuplicateNameCaseSensitive).unwrap().clone(),
+        DEFAULT_DUPLICATE_CASE_SENSITIVE_NAME_CHECKING,
+    );
 
     // Setting data
     if manual_execution || loading_at_start {
         {
+            // Handle here arguments that were added to app e.g. czkawka_gui /home --/home/roman
+            if loading_at_start && arguments.len() > 1 {
+                let iter_i = arguments.iter().skip(1);
+                let iter_e = iter_i.clone();
+                included_directories = iter_i
+                    .filter_map(|e| {
+                        let r = e.to_string_lossy().to_string();
+                        if !r.starts_with("--") {
+                            let path = Path::new(&r);
+                            if !path.exists() {
+                                return None;
+                            }
+                            match path.canonicalize() {
+                                Ok(r) => Some(r.to_string_lossy().to_string()),
+                                Err(_) => None,
+                            }
+                        } else {
+                            None
+                        }
+                    })
+                    .collect::<Vec<_>>();
+                excluded_directories = iter_e
+                    .filter_map(|e| {
+                        let r = e.to_string_lossy().to_string();
+                        if let Some(r) = r.strip_prefix("--") {
+                            let path = Path::new(&r);
+                            if !path.exists() {
+                                return None;
+                            }
+                            match path.canonicalize() {
+                                Ok(r) => Some(r.to_string_lossy().to_string()),
+                                Err(_) => None,
+                            }
+                        } else {
+                            None
+                        }
+                    })
+                    .collect::<Vec<_>>();
+            }
+
             // Include Directories
             let tree_view_included_directories = upper_notebook.tree_view_included_directories.clone();
             let list_store = get_list_store(&tree_view_included_directories);
@@ -812,12 +866,31 @@ pub fn load_configuration(
         save_proper_value_to_combo_box(&main_notebook.combo_box_image_hash_size, combo_box_image_hash_size);
         save_proper_value_to_combo_box(&main_notebook.combo_box_image_resize_algorithm, combo_box_image_resize_algorithm);
 
+        main_notebook.check_button_duplicate_case_sensitive_name.set_active(check_button_case_sensitive_name);
         main_notebook.entry_big_files_number.set_text(&number_of_biggest_files);
         main_notebook.check_button_image_ignore_same_size.set_active(similar_images_ignore_same_size);
         main_notebook.check_button_image_fast_compare.set_active(similar_images_fast_compare);
         main_notebook.check_button_video_ignore_same_size.set_active(similar_videos_ignore_same_size);
         main_notebook.scale_similarity_similar_videos.set_value(similar_videos_similarity as f64);
 
+        {
+            let combo_chosen_index = main_notebook.combo_box_duplicate_check_method.active().unwrap();
+
+            if DUPLICATES_CHECK_METHOD_COMBO_BOX[combo_chosen_index as usize].check_method == CheckingMethod::Hash {
+                main_notebook.combo_box_duplicate_hash_type.set_visible(true);
+                main_notebook.label_duplicate_hash_type.set_visible(true);
+            } else {
+                main_notebook.combo_box_duplicate_hash_type.set_visible(false);
+                main_notebook.label_duplicate_hash_type.set_visible(false);
+            }
+
+            if DUPLICATES_CHECK_METHOD_COMBO_BOX[combo_chosen_index as usize].check_method == CheckingMethod::Name {
+                main_notebook.check_button_duplicate_case_sensitive_name.set_visible(true);
+            } else {
+                main_notebook.check_button_duplicate_case_sensitive_name.set_visible(false);
+            }
+        }
+
         // Set size of similarity scale gtk node, must be set BEFORE setting value of this
         let index = main_notebook.combo_box_image_hash_size.active().unwrap() as usize;
 
